Bundle

Struct Bundle 

pub struct Bundle {
    pub header: FileHeader,
    pub manifest: Manifest,
    pub manifest_bytes: Vec<u8>,
    pub seal_bytes: Vec<u8>,
    pub index: Vec<IndexRecord>,
    pub data: Vec<u8>,
}
A parsed ahu bundle, loaded into memory.

Fields

header: FileHeadermanifest: Manifestmanifest_bytes: Vec<u8>seal_bytes: Vec<u8>index: Vec<IndexRecord>data: Vec<u8>

Implementations

Source

impl Bundle

pub fn from_file(path: &Path) -> Result<Self>

Read a bundle from a file path.

pub fn from_bytes(bytes: &[u8]) -> Result<Self>

Read a bundle from a byte slice.

pub fn to_bytes(&self) -> Result<Vec<u8>>

Serialize the already parsed sections without changing the signed manifest.

pub fn lookup(&self, entry_key: &[u8; 32]) -> Option<&[u8]>

Look up an entry by its entry key (SHA-256 of DER CertID). Returns the default (discriminator=0) entry.

pub fn lookup_preferred( &self, entry_key: &[u8; 32], preferences: &[u16], ) -> Option<&[u8]>

Look up the best-matching entry given a list of preferred discriminators.

pub fn entry_at(&self, idx: usize) -> Option<&[u8]>

pub fn entry_bytes(&self, record: &IndexRecord) -> Option<&[u8]>

Get the raw response bytes for an index record.